summaryrefslogtreecommitdiff
path: root/Master/tlpkg/TeXLive/TLTREE.pm
diff options
context:
space:
mode:
authorNorbert Preining <preining@logic.at>2007-06-28 09:21:34 +0000
committerNorbert Preining <preining@logic.at>2007-06-28 09:21:34 +0000
commitbd5eb7b6ea629f57c2f9b32fa9e650d25a3f2a4f (patch)
tree0953f033ef88fd4d6ce3c2f841de3997cba1fb5c /Master/tlpkg/TeXLive/TLTREE.pm
parentf82d752fb1943968e50950f963a3b1623b417963 (diff)
now also match .dll like .exe and .bat, again update .tlpsrc, man page
of TLPSRC. texlive.tlpdb didn't change (good) git-svn-id: svn://tug.org/texlive/trunk@4521 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Master/tlpkg/TeXLive/TLTREE.pm')
-rw-r--r--Master/tlpkg/TeXLive/TLTREE.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/Master/tlpkg/TeXLive/TLTREE.pm b/Master/tlpkg/TeXLive/TLTREE.pm
index 1246a6893a9..4d8ff67b675 100644
--- a/Master/tlpkg/TeXLive/TLTREE.pm
+++ b/Master/tlpkg/TeXLive/TLTREE.pm
@@ -243,10 +243,10 @@ sub _get_files_matching_glob_pattern {
}
}
if ($dirpart =~ m@^bin/win32@) {
# for arch=win32 under bin we also want to match .bat and .exe files
foreach my $f (@candfiles) {
&TeXLive::TLUtils::debug("matching $f in $dirpart via glob $globline.{bat/exe}\n");
- if ($f =~ /^$basepart\.(bat|exe)$/) {
+ if ($f =~ /^$basepart\.(bat|exe|dll)$/) {
&TeXLive::TLUtils::debug("hit: globline=$globline, $dirpart/$f\n");
push @returnfiles, "$dirpart/$f";
}
@@ -243,10 +243,10 @@ sub _get_files_matching_glob_pattern {
}
if ($dirpart =~ m@^bin/win32@) {
- # for arch=win32 under bin we also want to match .bat and .exe files
+ # for arch=win32 under bin we also want to match .dll, .bat, .exe files
foreach my $f (@candfiles) {
&TeXLive::TLUtils::debug("matching $f in $dirpart via glob $globline.{bat/exe}\n");